package view

import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.items
import androidx.compose.material.Card
import androidx.compose.material.ExperimentalMaterialApi
import androidx.compose.material.FilterChip
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.Dialog

@OptIn(ExperimentalMaterialApi::class)
@Composable
fun FilterCard(
    recipeTags: List<String>,
    onDismissRequest : (List<String>) -> Unit,
) {

    val tags by remember { mutableStateOf(recipeTags.sorted()) }
    var tagsFiltered: List<String> = listOf()

    Dialog(onDismissRequest = {

        onDismissRequest(tagsFiltered)

    }) {
        Card {
            LazyVerticalGrid(
                columns = GridCells.Adaptive(minSize = 128.dp)
            ) {
                items(tags) { tag ->
                    var selected by remember { mutableStateOf(false) }
                    FilterChip(
                        selected = selected,
                        onClick = {
                            selected = !selected
                            tagsFiltered = if(selected) {
                                tagsFiltered.plus(tag)
                            } else{
                                tagsFiltered.minus(tag)
                            }
                        },
                        content = { Text(tag) }
                    )
                }
            }
        }
    }
}