package view

import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.text.toLowerCase
import model.Recipe
import model.americanList
import model.exampleList

fun List<String>.containsPartial(text:String) : Boolean {
    return  this.any {it.lowercase().contains(text.lowercase())}
}

@Composable
fun getFilteredRecipeList(
    tags : List<String>,
    search : String,
    lockTag : String,
) : List<Recipe> {
    val items = getRecipeList()

    var recipes = items.filter { it.tags.keys.containsAll(tags) }

    recipes = recipes.filter {
        it.title.lowercase().contains(search.lowercase()) || it.ingredients.containsPartial(search)
    }

    if (lockTag != "")
    {
        recipes = recipes.filter { it.tags.contains(lockTag)}
    }

    recipes = recipes.sortedBy { it.title }

    return recipes
}

@Composable
fun getRecipeList() : List<Recipe> {
    val exampleRecipes by remember { mutableStateOf(exampleList) }
    val americanRecipes by remember { mutableStateOf(americanList) }
    val items : MutableList<Recipe> = mutableListOf()


    items.addAll(exampleRecipes)
    items.addAll(americanRecipes)

    return items
}